
USE [master]
GO

CREATE DATABASE WebDav
GO

USE [WebDav]
GO


/****** Object:  Table [dbo].[cal_Alarm] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[cal_Alarm](
	[AlarmId] [uniqueidentifier] NOT NULL CONSTRAINT [DF_cal_Alarm_AlarmId]  DEFAULT (newid()),
	[EventComponentId] [uniqueidentifier] NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[Action] [nvarchar](15) NOT NULL,
	[TriggerAbsoluteDateTimeUtc] [datetime2](7) NULL,
	[TriggerRelativeOffset] [bigint] NULL,
	[TriggerRelatedStart] [bit] NULL,
	[Summary] [nvarchar](255) NULL,
	[Description] [nvarchar](max) NULL,
	[Duration] [bigint] NULL,
	[Repeat] [int] NULL,
 CONSTRAINT [PK_cal_Alarm] PRIMARY KEY CLUSTERED 
(
	[AlarmId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO
/****** Object:  Table [dbo].[cal_Attachment] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET ANSI_PADDING ON
GO
CREATE TABLE [dbo].[cal_Attachment](
	[AttachmentId] [uniqueidentifier] NOT NULL,
	[EventComponentId] [uniqueidentifier] NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[MediaType] [nvarchar](50) NULL,
	[ExternalUrl] [nvarchar](max) NULL,
	[Content] [varbinary](max) NULL,
 CONSTRAINT [PK_cal_Attachment] PRIMARY KEY CLUSTERED 
(
	[AttachmentId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO
SET ANSI_PADDING OFF
GO
/****** Object:  Table [dbo].[cal_Attendee] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[cal_Attendee](
	[AttendeeId] [uniqueidentifier] NOT NULL CONSTRAINT [DF_cal_Attendee_AttendeeId]  DEFAULT (newid()),
	[EventComponentId] [uniqueidentifier] NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[Email] [nvarchar](50) NULL,
	[CommonName] [nvarchar](255) NULL,
	[DirectoryEntryRef] [nvarchar](max) NULL,
	[Language] [nvarchar](50) NULL,
	[UserType] [nvarchar](15) NULL,
	[SentBy] [nvarchar](50) NULL,
	[DelegatedFrom] [nvarchar](50) NULL,
	[DelegatedTo] [nvarchar](50) NULL,
	[Rsvp] [bit] NULL,
	[ParticipationRole] [nvarchar](15) NULL,
	[ParticipationStatus] [nvarchar](15) NULL,
 CONSTRAINT [PK_cal_Attendee] PRIMARY KEY CLUSTERED 
(
	[AttendeeId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO
/****** Object:  Table [dbo].[cal_CalendarFile] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[cal_CalendarFile](
	[UID] [nvarchar](255) NOT NULL,
	[CalendarFolderId] [uniqueidentifier] NOT NULL,
	[ETag] [timestamp] NOT NULL,
	[CreatedUtc] [datetime2](7) NOT NULL CONSTRAINT [DF_cal_CalendarFile_CreatedUtc]  DEFAULT (getutcdate()),
	[ModifiedUtc] [datetime2](7) NOT NULL CONSTRAINT [DF_cal_CalendarFile_ModifiedUtc]  DEFAULT (getutcdate()),
 CONSTRAINT [PK_cal_CalendarFile] PRIMARY KEY CLUSTERED 
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO
/****** Object:  Table [dbo].[cal_CalendarFolder] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[cal_CalendarFolder](
	[CalendarFolderId] [uniqueidentifier] NOT NULL CONSTRAINT [DF_cal_Calendar_CalendarFolderId]  DEFAULT (newid()),
	[Name] [nvarchar](50) NOT NULL,
	[Description] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_cal_Calendar] PRIMARY KEY CLUSTERED 
(
	[CalendarFolderId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO
INSERT INTO [dbo].[cal_CalendarFolder] ([Name] ,[Description]) VALUES (N'Cal 1', N'Calendar 1')

GO
/****** Object:  Table [dbo].[cal_CalendarFolderProperty] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[cal_CalendarFolderProperty](
	[CalendarFolderPropertyId] [uniqueidentifier] NOT NULL CONSTRAINT [DF_cal_CalendarFolderProperty_CalendarFolderPropertyId] DEFAULT (newid()),
	[CalendarFolderId] [uniqueidentifier] NOT NULL,
	[Name] [nvarchar](255) NOT NULL,
	[Namespace] [nvarchar](100) NOT NULL,
	[PropVal] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_cal_CalendarFolderProperty] PRIMARY KEY CLUSTERED 
(
	[CalendarFolderPropertyId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO
/****** Object:  Table [dbo].[cal_RecurrenceException] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[cal_RecurrenceException](
	[RecurrenceExceptionId] [uniqueidentifier] NOT NULL,
	[EventComponentId] [uniqueidentifier] NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[ExceptionDate] [datetime2](7) NOT NULL,
	[TimeZoneId] [nvarchar](255) NULL,
	[AllDay] [bit] NOT NULL,
 CONSTRAINT [PK_cal_RecurrenceException] PRIMARY KEY CLUSTERED 
(
	[RecurrenceExceptionId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO
/****** Object:  Table [dbo].[cal_EventComponent] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[cal_EventComponent](
	[EventComponentId] [uniqueidentifier] NOT NULL CONSTRAINT [DF_cal_EventComponent_EventComponentId]  DEFAULT (newid()),
	[UID] [nvarchar](255) NOT NULL,
	[ComponentType] [bit] NOT NULL,
	[DateTimeStampUtc] [datetime2](7) NOT NULL,
	[CreatedUtc] [datetime2](7) NULL,
	[LastModifiedUtc] [datetime2](7) NULL,
	[Summary] [nvarchar](511) NULL,
	[Description] [nvarchar](max) NULL,
	[OrganizerEmail] [nvarchar](255) NULL,
	[OrganizerCommonName] [nvarchar](50) NULL,
	[Start] [datetime2](7) NULL,
	[StartTimeZoneId] [nvarchar](255) NULL,
	[End] [datetime2](7) NULL,
	[EndTimeZoneId] [nvarchar](255) NULL,
	[Duration] [bigint] NULL,
	[AllDay] [bit] NULL,
	[Class] [nvarchar](50) NULL,
	[Location] [nvarchar](255) NULL,
	[Priority] [tinyint] NULL,
	[Sequence] [int] NULL,
	[Status] [nvarchar](50) NULL,
	[Categories] [nvarchar](255) NULL,
	[RecurFrequency] [nvarchar](50) NULL,
	[RecurInterval] [int] NULL,
	[RecurUntil] [datetime2](7) NULL,
	[RecurCount] [int] NULL,
	[RecurWeekStart] [nvarchar](50) NULL,
	[RecurByDay] [nvarchar](50) NULL,
	[RecurByMonthDay] [nvarchar](50) NULL,
	[RecurByMonth] [nvarchar](50) NULL,
	[RecurBySetPos] [nvarchar](50) NULL,
	[RecurrenceIdDate] [datetime2](7) NULL,
	[RecurrenceIdTimeZoneId] [nvarchar](255) NULL,
	[RecurrenceIdThisAndFuture] [bit] NULL,
	[EventTransparency] [bit] NULL,
	[ToDoCompletedUtc] [datetime2](7) NULL,
	[ToDoPercentComplete] [tinyint] NULL,
 CONSTRAINT [PK_cal_EventComponent] PRIMARY KEY CLUSTERED 
(
	[EventComponentId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO
/****** Object:  Table [dbo].[cal_CustomProperty] ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[cal_CustomProperty](
	[CustomPropertyId] [uniqueidentifier] NOT NULL CONSTRAINT [DF_cal_CustomProperty_CustomPropertyId]  DEFAULT (newid()),
	[ParentId] [uniqueidentifier] NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[PropertyName] [nvarchar](50) NOT NULL,
	[ParameterName] [nvarchar](50) NULL,
	[Value] [nvarchar](512) NOT NULL,
 CONSTRAINT [PK_cal_CustomProperty] PRIMARY KEY CLUSTERED 
(
	[CustomPropertyId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO

ALTER TABLE [dbo].[cal_Attachment] ADD  CONSTRAINT [DF_cal_Attachment_AttachmentId]  DEFAULT (newid()) FOR [AttachmentId]
GO
ALTER TABLE [dbo].[cal_RecurrenceException] ADD  CONSTRAINT [DF_cal_RecurrenceException_RecurrenceExceptionId]  DEFAULT (newid()) FOR [RecurrenceExceptionId]
GO

ALTER TABLE [dbo].[cal_Alarm]  WITH CHECK ADD  CONSTRAINT [FK_cal_Alarm_EventComponent] FOREIGN KEY([EventComponentId])
REFERENCES [dbo].[cal_EventComponent] ([EventComponentId])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[cal_Alarm] CHECK CONSTRAINT [FK_cal_Alarm_EventComponent]
GO

ALTER TABLE [dbo].[cal_Attachment]  WITH CHECK ADD  CONSTRAINT [FK_cal_Attachment_EventComponent] FOREIGN KEY([EventComponentId])
REFERENCES [dbo].[cal_EventComponent] ([EventComponentId])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[cal_Attachment] CHECK CONSTRAINT [FK_cal_Attachment_EventComponent]
GO

ALTER TABLE [dbo].[cal_Attendee]  WITH CHECK ADD  CONSTRAINT [FK_cal_Attendee_EventComponent] FOREIGN KEY([EventComponentId])
REFERENCES [dbo].[cal_EventComponent] ([EventComponentId])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[cal_Attendee] CHECK CONSTRAINT [FK_cal_Attendee_EventComponent]
GO

ALTER TABLE [dbo].[cal_CalendarFile]  WITH CHECK ADD  CONSTRAINT [FK_cal_CalendarFile_Calendar] FOREIGN KEY([CalendarFolderId])
REFERENCES [dbo].[cal_CalendarFolder] ([CalendarFolderId])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[cal_CalendarFile] CHECK CONSTRAINT [FK_cal_CalendarFile_Calendar]
GO

ALTER TABLE [dbo].[cal_CalendarFolderProperty]  WITH CHECK ADD  CONSTRAINT [FK_cal_CalendarFolderProperty_CalendarFolder] FOREIGN KEY([CalendarFolderId])
REFERENCES [dbo].[cal_CalendarFolder] ([CalendarFolderId])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[cal_CalendarFolderProperty] CHECK CONSTRAINT [FK_cal_CalendarFolderProperty_CalendarFolder]
GO

ALTER TABLE [dbo].[cal_RecurrenceException]  WITH CHECK ADD  CONSTRAINT [FK_cal_RecurrenceException_EventComponent] FOREIGN KEY([EventComponentId])
REFERENCES [dbo].[cal_EventComponent] ([EventComponentId])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[cal_RecurrenceException] CHECK CONSTRAINT [FK_cal_RecurrenceException_EventComponent]
GO

ALTER TABLE [dbo].[cal_EventComponent]  WITH CHECK ADD  CONSTRAINT [FK_cal_EventComponent_CalendarFile] FOREIGN KEY([UID])
REFERENCES [dbo].[cal_CalendarFile] ([UID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[cal_EventComponent] CHECK CONSTRAINT [FK_cal_EventComponent_CalendarFile]
GO

ALTER TABLE [dbo].[cal_CustomProperty]  WITH CHECK ADD  CONSTRAINT [FK_cal_CustomProperty_CalendarFile] FOREIGN KEY([UID])
REFERENCES [dbo].[cal_CalendarFile] ([UID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[cal_CustomProperty] CHECK CONSTRAINT [FK_cal_CustomProperty_CalendarFile]
GO

/****** Object:  Index [IX_cal_CalendarFolderProperty] ******/
CREATE NONCLUSTERED INDEX [IX_cal_CalendarFolderProperty] ON [dbo].[cal_CalendarFolderProperty]
(
	[CalendarFolderId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_cal_CalendarFile] ******/
CREATE NONCLUSTERED INDEX [IX_cal_CalendarFile] ON [dbo].[cal_CalendarFile]
(
	[CalendarFolderId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_cal_EventComponent] ******/
CREATE NONCLUSTERED INDEX [IX_cal_EventComponent] ON [dbo].[cal_EventComponent]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_cal_RecurrenceException] ******/
CREATE NONCLUSTERED INDEX [IX_cal_RecurrenceException] ON [dbo].[cal_RecurrenceException]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_cal_Alarm] ******/
CREATE NONCLUSTERED INDEX [IX_cal_Alarm] ON [dbo].[cal_Alarm]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_cal_Attendee] ******/
CREATE NONCLUSTERED INDEX [IX_cal_Attendee] ON [dbo].[cal_Attendee]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_cal_Attachment] ******/
CREATE NONCLUSTERED INDEX [IX_cal_Attachment] ON [dbo].[cal_Attachment]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_cal_CustomProperty] ******/
CREATE NONCLUSTERED INDEX [IX_cal_CustomProperty] ON [dbo].[cal_CustomProperty]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'AlarmId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Component to which this alarm belongs.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'EventComponentId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Event or to-do (calendar file) to which this alarm belongs. Only required here to reduce ammount of joins.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Defines which action to be invoked when an alarm is triggered (AUDIO/DISPLAY/EMAIL).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'Action'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The absolute date-time for the alarm in UTC. NULL if relative time is specified.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'TriggerAbsoluteDateTimeUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The time for the trigger of the alarm relative to the start or the end of an event or to-do. NULL if absolute time is specified.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'TriggerRelativeOffset'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Relationship of the alarm trigger with respect to the start or end of the calendar component in case relative time is specified. NULL if absolute date-time is specified.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'TriggerRelatedStart'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Text to be used as the message subject when the Action is EMAIL.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'Summary'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Text to be displayed when the alarm is triggered if the Action is DISPLAY or the e-mail message body when the Action is EMAIL.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'Description'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Alarm duration in ticks. 1 tick = 100 nanoseconds.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'Duration'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The number of times the alarm should be repeated, after the initial trigger.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm', @level2type=N'COLUMN',@level2name=N'Repeat'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'A reminder or alarm for an event or a to-do.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Alarm'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Component to which this attchment belongs.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attachment', @level2type=N'COLUMN',@level2name=N'EventComponentId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Event or to-do (calendar file) to which this attachment belongs. Only required here to reduce ammount of joins.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attachment', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Media type. Typically NULL when external URL is specified.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attachment', @level2type=N'COLUMN',@level2name=N'MediaType'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Attachment URL. NULL if file content is specified.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attachment', @level2type=N'COLUMN',@level2name=N'ExternalUrl'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Attacment file content. NULL if external url is specified. It is recommended to keep attchment size below 256Kb. In case over 1Mb should be stored, convert to FILESTREAM, FileTable or store in file system.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attachment', @level2type=N'COLUMN',@level2name=N'Content'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Contains event and to-do attchments.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attachment'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Component to which this this attendee is assigned.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'EventComponentId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Event or to-do (calendar file) to which this attendee belongs. Only required here to reduce ammount of joins.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Attengee e-mail.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'Email'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Attendee common name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'CommonName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Reference to a directory entry associated with the attendee.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'DirectoryEntryRef'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Language.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'Language'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Calendar user type (INDIVIDUAL/GROUP/RESOURCE/ROOM/UNKNOWN)' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'UserType'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Used to indicate whom is acting on behalf of the attendee. Typically e-mail.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'SentBy'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Used to indicate whom the request was delegated from. Typically e-mail.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'DelegatedFrom'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Used to indicate the calendar users that the original request was delegated to. Typically e-mail.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'DelegatedTo'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Used for indicating whether the favor of a reply is requested.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'Rsvp'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Used to specify the participation role (CHAIR/REQ-PARTICIPANT/OPT-PARTICIPANT/NON-PARTICIPANT).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'ParticipationRole'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Used to specify participation status (NEEDS-ACTION/ACCEPTED/DECLINED/TENTATIVE/DELEGATED/COMPLETED/IN-PROCESS).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee', @level2type=N'COLUMN',@level2name=N'ParticipationStatus'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores attendees for an event, to-do, journal and free-busy calendar components.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_Attendee'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Event or to-do (calendar file) UID. All events or to-dos components withing a file has this UID.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFile', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Calendar (calendar folder) to which this component belongs to.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFile', @level2type=N'COLUMN',@level2name=N'CalendarFolderId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Automaticaly changes each time this object is updated. Used for synchronization operations.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFile', @level2type=N'COLUMN',@level2name=N'ETag'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Time when this file was created. Typically CalDAV clients never request this property, used for demo purposes only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFile', @level2type=N'COLUMN',@level2name=N'CreatedUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Time when this file was modified. This property is updated to trigger ETag update. Typically CalDAV clients never request this property, used for demo purposes only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFile', @level2type=N'COLUMN',@level2name=N'ModifiedUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Contains calendar files (.ics). Each file contains one or more event or to-do instances.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFile'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Calendar name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFolder', @level2type=N'COLUMN',@level2name=N'Name'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Calendar description.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFolder', @level2type=N'COLUMN',@level2name=N'Description'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Contains calendars (calendar folders). Calendar folder contains calendar files each containing event or to-do description.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFolder'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Calendar (calendar folder) to which this custom property belongs to.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFolderProperty', @level2type=N'COLUMN',@level2name=N'CalendarFolderId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Custom property name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFolderProperty', @level2type=N'COLUMN',@level2name=N'Name'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Custom property namespace.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFolderProperty', @level2type=N'COLUMN',@level2name=N'Namespace'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Custom property value.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFolderProperty', @level2type=N'COLUMN',@level2name=N'PropVal'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Calendar WebDAV custom properties.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CalendarFolderProperty'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Component to which this this recurrence rule exception belongs.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_RecurrenceException', @level2type=N'COLUMN',@level2name=N'EventComponentId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Event or to-do (calendar file) to which this recurrence exception belongs. Only required here to reduce ammount of joins.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_RecurrenceException', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Recurrence exception date.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_RecurrenceException', @level2type=N'COLUMN',@level2name=N'ExceptionDate'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Recurrence exception date time zone ID. If if NULL - ExceptionDate is a "floating" time. If contains "UTC" - the ExceptionDate is in UTC.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_RecurrenceException', @level2type=N'COLUMN',@level2name=N'TimeZoneId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Time in ExceptionDate should be ignored for all-day events or to-dos.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_RecurrenceException', @level2type=N'COLUMN',@level2name=N'AllDay'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Contains exceptions for recurring events and to-dos.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_RecurrenceException'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'EventComponentId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Event or to-do (calendar file) to which this component belongs to.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Type of component. 1 - event, 0 - to-do.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'ComponentType'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Specifies the date and time in UTC when the object was created.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'DateTimeStampUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Specifies the date and time in UTC when the calendar information was created by the calendar user agent in the calendar store.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'CreatedUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Specifies the date and time in UTC when the information associated with the calendar component was last revised in the calendar store.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'LastModifiedUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Defines a short summary or subject.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Summary'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Provides a more complete description of the calendar component than that provided by the "SUMMARY" property.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Description'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Specifies e-mail of the organizer of the event or to-do.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'OrganizerEmail'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Specifies common name  of the organizer of the event or to-do.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'OrganizerCommonName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Specifies the inclusive start of the event or to-do. For recurring events and to-dos, it also specifies the very first recurrence instance. Could be "floating" time, time relative to time zone in StartTimeZone field or UTC.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Start'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Time zone ID for event or to-do Start time. If if NULL - Start is a "floating" time. If contains "UTC" - Start is in UTC.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'StartTimeZoneId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Specifies the non-inclusive end of the event or due time for to-do component. Could be "floating" time, time relative to time zone in EndTimeZone field or UTC. NULL if Duration is specified.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'End'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Time zone ID for event End or to-do due time. If if NULL - End is a "floating" time. If contains "UTC" - the End is in UTC. Contains NULL if Duration is specified.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'EndTimeZoneId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Event or to-do duration in ticks. 1 tick = 100 nanoseconds. NULL if End is specified.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Duration'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'True for all-day event or to-do. Time in Start and End/Due property should be ignored for all-day events or to-dos. StartTimeZone/EndTimeZone must be set to NULL for all-day events and to-dos.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'AllDay'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Specifies access classification (PUBLIC/PRIVATE/CONFIDENTIAL).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Class'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Location description.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Location'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Relative priority (0-9). A value of 0 specifies an undefined priority. A value of 1 is the highest priority.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Priority'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Defines the revision sequence number of the calendar component within a sequence of revisions.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Sequence'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Overall status or confirmation for the event or to-do (TENTATIVE/CONFIRMED/CANCELLED).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Status'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Specifies categories or subtypes of the calendar component, coma-separated list.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'Categories'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Recurrence rule frequency (SECONDLY/MINUTELY/HOURLY/DAILY/WEEKLY/MONTHLY/YEARLY).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurFrequency'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Positive integer representing at which intervals the recurrence rule repeats.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurInterval'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Date-time untill which the recurrence rule is valid. Could be "floating" time or UTC, depending on Start value.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurUntil'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Contains the number of occurrences at which to range-bound the recurrence.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurCount'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'RecurWeekStart.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurWeekStart'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Days of the week for weekly, monthly or yearly recurrence rule separated with '',''. For example: ''TU,WE,FR'' or ''1SU,-1SU''.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurByDay'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Comma-separated list of days of the month. Valid values are 1 to 31 or -31 to -1.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurByMonthDay'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Comma-separated list of months of the year. Valid values are 1 to 12.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurByMonth'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Comma-separated list of days of the month. Valid values are 1 to 31 or -31 to -1.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurBySetPos'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Recurrence ID date or date and time. The value must be of the same type as Start value: "floating" time, UTC, or time in specific time zone.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurrenceIdDate'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Recurrence ID time zone ID.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurrenceIdTimeZoneId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Recurrence ID RANGE parameter. If true - indicates a range defined by the given recurrence instance and all subsequent instances.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'RecurrenceIdThisAndFuture'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Defines whether or not an event is transparent to busy time searches. Valid for events only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'EventTransparency'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Defines the date and time in UTC that a to-do was actually completed. Valid for to-dos only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'ToDoCompletedUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Percent completion of a to-do. Valid for to-dos only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent', @level2type=N'COLUMN',@level2name=N'ToDoPercentComplete'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores calendars events and to-dos components (VEVENT and VTODO). Every calendar file can contain more than one component all sharing the same UID.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_EventComponent'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Parent component ID or parent property ID to which this custom property or parameter belongs to. This could be EventComponentId, AlarmId, AttachmentId, AttendeeId.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CustomProperty', @level2type=N'COLUMN',@level2name=N'ParentId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Event or to-do (calendar file) to which this custom property or property parameter belongs to.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CustomProperty', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Property name. This could be a custom property name (starting with ''X-'') or standard property name in case standard property contains custom parameters.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CustomProperty', @level2type=N'COLUMN',@level2name=N'PropertyName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Parameter name. If null - Value field contains property value. Otherwise Value field contains parameter value.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CustomProperty', @level2type=N'COLUMN',@level2name=N'ParameterName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Property or parameter value. If ParameterName is null - this is a property value. If ParameterName is not null - this is a parameter value.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CustomProperty', @level2type=N'COLUMN',@level2name=N'Value'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores iCalendar custom properties and parameters.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'cal_CustomProperty'
GO


/****** Object:  Table [dbo].[card_Address] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[card_Address](
	[AddressId] [uniqueidentifier] NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[Type] [nvarchar](50) NULL,
	[PoBox] [nvarchar](50) NULL,
	[AppartmentNumber] [nvarchar](15) NULL,
	[Street] [nvarchar](255) NULL,
	[Locality] [nvarchar](50) NULL,
	[Region] [nvarchar](50) NULL,
	[PostalCode] [nvarchar](15) NULL,
	[Country] [nvarchar](50) NULL,
	[PreferenceLevel] [tinyint] NULL,
	[Label] [nvarchar](50) NULL,
	[Geo] [geography] NULL,
	[TimeZone] [nvarchar](50) NULL,
 CONSTRAINT [PK_card_Address] PRIMARY KEY CLUSTERED 
(
	[AddressId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO
/****** Object:  Table [dbo].[card_AddressbookFolder] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[card_AddressbookFolder](
	[AddressbookFolderId] [uniqueidentifier] NOT NULL CONSTRAINT [DF_card_AddressbookFolder_AddressbookFolderId]  DEFAULT (newid()),
	[Name] [nvarchar](50) NOT NULL,
	[Description] [nvarchar](50) NOT NULL,
 CONSTRAINT [PK_card_AddressbookFolder] PRIMARY KEY CLUSTERED 
(
	[AddressbookFolderId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

INSERT INTO [dbo].[card_AddressbookFolder] ([Name] ,[Description]) VALUES (N'Book 1', N'Addressbook 1')
GO

/****** Object:  Table [dbo].[card_AddressbookFolderProperty] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[card_AddressbookFolderProperty](
	[AddressbookFolderPropertyId] [uniqueidentifier] NOT NULL CONSTRAINT [DF_card_AddressbookFolderProperty_AddressbookFolderPropertyId] DEFAULT (newid()),
	[AddressbookFolderId] [uniqueidentifier] NOT NULL,
	[Name] [nvarchar](255) NOT NULL,
	[Namespace] [nvarchar](100) NOT NULL,
	[PropVal] [nvarchar](255) NOT NULL,
 CONSTRAINT [PK_card_AddressbookFolderProperty] PRIMARY KEY CLUSTERED 
(
	[AddressbookFolderPropertyId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[card_CardFile] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET ANSI_PADDING ON
GO
CREATE TABLE [dbo].[card_CardFile](
	[UID] [nvarchar](255) NOT NULL,
	[AddressbookFolderId] [uniqueidentifier] NOT NULL,
	[ETag] [timestamp] NOT NULL,
	[CreatedUtc] [datetime2](7) NOT NULL CONSTRAINT [DF_card_CardFile_CreatedUtc]  DEFAULT (getutcdate()),
	[ModifiedUtc] [datetime2](7) NOT NULL CONSTRAINT [DF_card_CardFile_ModifiedUtc]  DEFAULT (getutcdate()),
	[Version] [nvarchar](3) NOT NULL,
	[FormattedName] [nvarchar](255) NOT NULL,
	[FamilyName] [nvarchar](50) NOT NULL,
	[GivenName] [nvarchar](50) NOT NULL,
	[AdditionalNames] [nvarchar](50) NOT NULL,
	[HonorificPrefix] [nvarchar](50) NOT NULL,
	[HonorificSuffix] [nvarchar](50) NOT NULL,
	[Product] [nvarchar](50) NULL,
	[Kind] [nvarchar](15) NULL,
	[Nickname] [nvarchar](50) NULL,
	[Photo] [varbinary](max) NULL,
	[PhotoMediaType] [nvarchar](15) NULL,
	[Logo] [varbinary](max) NULL,
	[LogoMediaType] [nvarchar](15) NULL,
	[Sound] [varbinary](max) NULL,
	[SoundMediaType] [nvarchar](15) NULL,
	[Birthday] [date] NULL,
	[Anniversary] [date] NULL,
	[Gender] [nvarchar](1) NULL,
	[RevisionUtc] [datetime2](7) NULL,
	[SortString] [nvarchar](255) NULL,
	[Language] [nvarchar](50) NULL,
	[TimeZone] [nvarchar](50) NULL,
	[Geo] [geography] NULL,
	[Title] [nvarchar](255) NULL,
	[Role] [nvarchar](255) NULL,
	[OrgName] [nvarchar](255) NULL,
	[OrgUnit] [nvarchar](255) NULL,
	[Categories] [nvarchar](255) NULL,
	[Note] [nvarchar](max) NULL,
	[Classification] [nvarchar](50) NULL,
 CONSTRAINT [PK_card_CardFile] PRIMARY KEY CLUSTERED 
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO
SET ANSI_PADDING OFF
GO
/****** Object:  Table [dbo].[card_Email] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[card_Email](
	[EmailId] [uniqueidentifier] NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[Type] [nvarchar](50) NULL,
	[Email] [nvarchar](50) NOT NULL,
	[PreferenceLevel] [tinyint] NULL,
 CONSTRAINT [PK_card_Email] PRIMARY KEY CLUSTERED 
(
	[EmailId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[card_InstantMessenger] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[card_InstantMessenger](
	[InstantMessengerId] [uniqueidentifier] NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[Type] [nvarchar](50) NULL,
	[InstantMessenger] [nvarchar](50) NOT NULL,
	[PreferenceLevel] [tinyint] NULL,
 CONSTRAINT [PK_card_InstantMessenger] PRIMARY KEY CLUSTERED 
(
	[InstantMessengerId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[card_Telephone] ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[card_Telephone](
	[TelephoneId] [uniqueidentifier] NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[Type] [nvarchar](50) NULL,
	[Telephone] [nvarchar](20) NOT NULL,
	[PreferenceLevel] [tinyint] NULL,
 CONSTRAINT [PK_card_Telephone] PRIMARY KEY CLUSTERED 
(
	[TelephoneId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[card_CustomProperty] ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[card_CustomProperty](
	[CustomPropertyId] [uniqueidentifier] NOT NULL CONSTRAINT [DF_card_CustomProperty_CustomPropertyId]  DEFAULT (newid()),
	[ParentId] [nvarchar](255) NOT NULL,
	[UID] [nvarchar](255) NOT NULL,
	[PropertyName] [nvarchar](50) NOT NULL,
	[ParameterName] [nvarchar](50) NULL,
	[Value] [nvarchar](512) NOT NULL,
 CONSTRAINT [PK_card_CustomProperty] PRIMARY KEY CLUSTERED 
(
	[CustomPropertyId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
)

GO


ALTER TABLE [dbo].[card_Address]  WITH CHECK ADD  CONSTRAINT [FK_card_Address_Card] FOREIGN KEY([UID])
REFERENCES [dbo].[card_CardFile] ([UID])
GO
ALTER TABLE [dbo].[card_Address] CHECK CONSTRAINT [FK_card_Address_Card]
GO
ALTER TABLE [dbo].[card_AddressbookFolderProperty]  WITH CHECK ADD  CONSTRAINT [FK_card_AddressbookFolderProperty_AddressbookFolder] FOREIGN KEY([AddressbookFolderId])
REFERENCES [dbo].[card_AddressbookFolder] ([AddressbookFolderId])
GO
ALTER TABLE [dbo].[card_AddressbookFolderProperty] CHECK CONSTRAINT [FK_card_AddressbookFolderProperty_AddressbookFolder]
GO
ALTER TABLE [dbo].[card_CardFile]  WITH CHECK ADD  CONSTRAINT [FK_card_CardFile_AddressbookFolder] FOREIGN KEY([AddressbookFolderId])
REFERENCES [dbo].[card_AddressbookFolder] ([AddressbookFolderId])
GO
ALTER TABLE [dbo].[card_CardFile] CHECK CONSTRAINT [FK_card_CardFile_AddressbookFolder]
GO

ALTER TABLE [dbo].[card_Email]  WITH CHECK ADD  CONSTRAINT [FK_card_Email_Card] FOREIGN KEY([UID])
REFERENCES [dbo].[card_CardFile] ([UID])
GO
ALTER TABLE [dbo].[card_Email] CHECK CONSTRAINT [FK_card_Email_Card]
GO

ALTER TABLE [dbo].[card_InstantMessenger]  WITH CHECK ADD  CONSTRAINT [FK_card_InstantMessenger_Card] FOREIGN KEY([UID])
REFERENCES [dbo].[card_CardFile] ([UID])
GO
ALTER TABLE [dbo].[card_InstantMessenger] CHECK CONSTRAINT [FK_card_InstantMessenger_Card]
GO

ALTER TABLE [dbo].[card_Telephone]  WITH CHECK ADD  CONSTRAINT [FK_card_Telephone_Card] FOREIGN KEY([UID])
REFERENCES [dbo].[card_CardFile] ([UID])
GO
ALTER TABLE [dbo].[card_Telephone] CHECK CONSTRAINT [FK_card_Telephone_Card]
GO

ALTER TABLE [dbo].[card_CustomProperty]  WITH CHECK ADD  CONSTRAINT [FK_card_CustomProperty_Card] FOREIGN KEY([UID])
REFERENCES [dbo].[card_CardFile] ([UID])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[card_CustomProperty] CHECK CONSTRAINT [FK_card_CustomProperty_Card]
GO

/****** Object:  Index [IX_card_AddressbookFolderProperty] ******/
CREATE NONCLUSTERED INDEX [IX_card_AddressbookFolderProperty] ON [dbo].[card_AddressbookFolderProperty]
(
	[AddressbookFolderId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_card_CardFile] ******/
CREATE NONCLUSTERED INDEX [IX_card_CardFile] ON [dbo].[card_CardFile]
(
	[AddressbookFolderId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_card_Email] ******/
CREATE NONCLUSTERED INDEX [IX_card_Email] ON [dbo].[card_Email]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_card_InstantMessenger] ******/
CREATE NONCLUSTERED INDEX [IX_card_InstantMessenger] ON [dbo].[card_InstantMessenger]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_card_Address] ******/
CREATE NONCLUSTERED INDEX [IX_card_Address] ON [dbo].[card_Address]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_card_Telephone] ******/
CREATE NONCLUSTERED INDEX [IX_card_Telephone] ON [dbo].[card_Telephone]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

/****** Object:  Index [IX_card_CustomProperty] ******/
CREATE NONCLUSTERED INDEX [IX_card_CustomProperty] ON [dbo].[card_CustomProperty]
(
	[UID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Card ID to which this address belongs.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Coma separated list of type flags (WORK/HOME/DOM/INTL/POSTAL/PARCEL/etc.)' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'Type'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'PO box. For max interoperability, should be empty.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'PoBox'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Appartment number. For max interoperability, should be empty.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'AppartmentNumber'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Street name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'Street'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'City name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'Locality'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Region (e.g., state or province).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'Region'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Postal code.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'PostalCode'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Country name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'Country'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores prefernce level for vCard 4.0. 1-100, 1-most prefered. In case of vCard 3.0 stores 1 for prefered property.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'PreferenceLevel'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Delivery address label.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'Label'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Coordinates associated with this address. vCard 4.0 only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'Geo'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Time zone for this address. vCard 4.0 only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address', @level2type=N'COLUMN',@level2name=N'TimeZone'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores addresses.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Address'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Address book name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_AddressbookFolder', @level2type=N'COLUMN',@level2name=N'Name'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Address book description.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_AddressbookFolder', @level2type=N'COLUMN',@level2name=N'Description'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Contain CardDAV addressbooks (addressbook folders)' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_AddressbookFolder'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Addressbook to which this custom property belongs to.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_AddressbookFolderProperty', @level2type=N'COLUMN',@level2name=N'AddressbookFolderId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Custom property name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_AddressbookFolderProperty', @level2type=N'COLUMN',@level2name=N'Name'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Custom property namespace.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_AddressbookFolderProperty', @level2type=N'COLUMN',@level2name=N'Namespace'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Custom property value.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_AddressbookFolderProperty', @level2type=N'COLUMN',@level2name=N'PropVal'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Addressbook WebDAV custom properties.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_AddressbookFolderProperty'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Business card UID' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Address book (address book folder) to which this business card belongs.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'AddressbookFolderId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'vCard version - 2.1/3.0/4.0.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Version'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Client app that created this card. For exmple -//Apple Inc.//iOS 10.0.2//EN' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Product'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Formatted name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'FormattedName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Last name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'FamilyName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'First name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'GivenName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Middle names, coma-separated list.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'AdditionalNames'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Honorific prefix.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'HonorificPrefix'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Honorific suffix.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'HonorificSuffix'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Kind of object the business card represents (individual/group/org/locaton). vCard 4.0 only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Kind'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Business card nickname.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Nickname'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Photoghraph image associated with this business card, typically when bysiness card represents an individual.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Photo'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Photo media type. PNG/JPEG/etc.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'PhotoMediaType'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Logo associated with this business card typically when bysiness card represents an organization.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Logo'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Logo media type. PNG/JPEG/etc.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'LogoMediaType'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Digital sound content associated with this business card.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Sound'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Sound media type. PNG/JPEG/etc.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'SoundMediaType'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Birth date of the object the business card represents. vCard 4.0 only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Birthday'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Anniversary of the object the business card represents. vCard 4.0 only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Anniversary'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Gender of the identity this business card represents (M - male, F- female, O - other, N - none, U - unknown). vCard 4.0 only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Gender'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Revision date-time in UTC.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'RevisionUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Text to be used as a sort string when displaying info on a client side. Typically family name or combination of family name and given name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'SortString'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Language used for contacting. vCard 4.0 only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Language'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Represents information related to the time zone of the business object.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'TimeZone'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Business object location - latitude and longitude.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Geo'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The position or job of the business card.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Title'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The function or part played in a particular situation by the business object.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Role'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Organization name.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'OrgName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Organization unit.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'OrgUnit'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Tags associated with business card.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Categories'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Business card supplemental information or a comment.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Note'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Business card access classification.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'Classification'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores business card (vCard files).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Automaticaly changes each time this object is updated.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'ETag'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Time when this file was created. Typically CardDAV clients never request this property, used for demo purposes only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'CreatedUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Time when this file was modified. This property is updated to trigger ETag update. Typically CardDAV clients never request this property, used for demo purposes only.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CardFile', @level2type=N'COLUMN',@level2name=N'ModifiedUtc'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Card ID to which this telephone belongs.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Email', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Coma separated list of type flags (WORK/HOME/INTERNET/X400/etc.).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Email', @level2type=N'COLUMN',@level2name=N'Type'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'E-mail.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Email', @level2type=N'COLUMN',@level2name=N'Email'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores prefernce level for vCard 4.0. 1-100, 1-most prefered. In case of vCard 2.1 and 3.0 stores 1 for prefered property.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Email', @level2type=N'COLUMN',@level2name=N'PreferenceLevel'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores e-mails.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Email'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Card ID to which this instant messenger belongs.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_InstantMessenger', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Coma separated list of type flags (WORK/HOME/PERSONAL/BUSINESS/MOBILE/etc.).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_InstantMessenger', @level2type=N'COLUMN',@level2name=N'Type'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Instant messenger.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_InstantMessenger', @level2type=N'COLUMN',@level2name=N'InstantMessenger'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores prefernce level for vCard 4.0. 1-100, 1-most prefered. In case of vCard 2.1 and 3.0 stores 1 for prefered property.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_InstantMessenger', @level2type=N'COLUMN',@level2name=N'PreferenceLevel'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores stores instant messengers.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_InstantMessenger'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Card ID to which this telephone belongs.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Telephone', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Coma separated list of type flags (WORK/HOME/TEXT/TEXTPHONE/PCS/VOICE/FAX/MSG/CELL/PAGER/BBS/MODEM/CAR/ISDN/VIDEO/etc.).' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Telephone', @level2type=N'COLUMN',@level2name=N'Type'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Telephone.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Telephone', @level2type=N'COLUMN',@level2name=N'Telephone'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores prefernce level for vCard 4.0. 1-100, 1-most prefered. In case of vCard 2.1 and 3.0 stores 1 for prefered property.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Telephone', @level2type=N'COLUMN',@level2name=N'PreferenceLevel'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores telephones' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_Telephone'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Parent Card ID or parent property ID to which this custom property or parameter belongs to. This could be UID, EmailId, InstantMessengerId, AddressId, TelephoneId.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CustomProperty', @level2type=N'COLUMN',@level2name=N'ParentId'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Card ID to which this custom property or property parameter belongs to.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CustomProperty', @level2type=N'COLUMN',@level2name=N'UID'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Property name. This could be a custom property name (starting with ''X-'') or standard property name in case standard property contains custom parameters.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CustomProperty', @level2type=N'COLUMN',@level2name=N'PropertyName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Parameter name. If null - Value field contains property value. Otherwise Value field contains parameter value.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CustomProperty', @level2type=N'COLUMN',@level2name=N'ParameterName'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Property or parameter value. If ParameterName is null - this is a property value. If ParameterName is not null - this is a parameter value.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CustomProperty', @level2type=N'COLUMN',@level2name=N'Value'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Stores vCard custom properties and parameters.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'card_CustomProperty'
GO
